@@ -11,7 +11,6 @@ from pyqt_svg_label import SvgLabel
 
 from pyqt_windows_buttons_widget import WindowsButtonsWidget
 from pyqt_mac_buttons_widget import MacButtonsWidget
-from pyqt_resource_helper import PyQtResourceHelper
 import absresgetter
 
 
@@ -216,6 +215,9 @@ class CustomTitlebarWindow(FramelessWindow):
             self.initButtonsEvent()
             lay.addWidget(self.__btnWidget)
 
+            w = h = self.__titleLbl.font().pointSize() * 3 * qApp.screens()[0].logicalDotsPerInch()/96.0
+            self.__btnWidget.setButtonSize(w, h)
+
             cornerWidget = QWidget()
             cornerWidget.setLayout(lay)
             # set the corner widget that already exists in QMenuBar
@@ -267,7 +269,8 @@ class CustomTitlebarWindow(FramelessWindow):
         # set menu icon
         self.__iconLbl = SvgLabel()
         self.__iconLbl.setSvgFile(icon_filename)
-        self.__iconLbl.setFixedSize(self.__menubar.sizeHint().height() // 1.2, self.__menubar.sizeHint().height() // 1.2)
+        w = h = self.__titleLbl.font().pointSize()*2*qApp.screens()[0].logicalDotsPerInch()/96.0
+        self.__iconLbl.setFixedSize(w, h)
         self.__menubar.setCornerWidget(self.__iconLbl, Qt.TopLeftCorner)
         self.__setWindowIcon(icon_filename)
 
